@@ -15,6 +15,9 @@ res <- Wald_test_cwb(full_model = full_model,
                      R = 99)
 
 test_that("plot() returns a ggplot2 object when run on a Wald_test_wildemeta",{
+
+  skip_if_not_installed("ggplot2")
+
   x <- plot(res)
   y <-
     plot(res, fill = "purple", alpha = 0.5) +
@@ -27,6 +30,9 @@ test_that("plot() returns a ggplot2 object when run on a Wald_test_wildemeta",{
 
 
 test_that("plot() throws an error if ggplot2 is not installed.", {
+
+  skip_if_not_installed("mockery")
+
   mockery::stub(plot.Wald_test_wildmeta, 'ggplot2_is_missing', TRUE)
   expect_error(plot(res))
 })
